==> gnucash_2.4.0.orig.tar.bz2: gnucash-2.4.0/src/core-utils/gnc-main.c <==
/*
 * gnc-main.c:
 *
 * Copyright (C) 2006 Chris Shoemaker <c.shoemaker@cox.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, contact:
 *
 * Free Software Foundation           Voice:  +1-617-542-5942
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
 * Boston, MA  02110-1301,  USA       gnu@gnu.org
 */

#include <stdlib.h>
#include "config.h"
#include "gnc-main.h"
#include "core-utils/gnc-version.h"

static gchar *namespace_regexp = NULL;
static gboolean is_debugging = 0;
static gboolean extras_enabled = 0;
static const gchar *gconf_path;

void
gnc_main_set_namespace_regexp(const gchar *str)
{
    if (namespace_regexp)
        g_free(namespace_regexp);

    if (str)
        namespace_regexp = g_strdup(str);
}

const gchar *
gnc_main_get_namespace_regexp(void)
{
    return namespace_regexp;
}

gboolean
gnc_is_debugging(void)
{
    return is_debugging;
}

void
gnc_set_debugging(gboolean d)
{
    is_debugging = d;
}

gboolean
gnc_is_extra_enabled(void)
{
    return extras_enabled;
}

void
gnc_set_extra(gboolean enabled)
{
    extras_enabled = enabled;
}

void
gnc_set_gconf_path (const gchar *path)
{
    gconf_path = path;
}

const gchar *
gnc_get_gconf_path (void)
{
    return gconf_path;
}

gint
gnc_get_svn_version (void)
{
    return strtol(GNUCASH_SVN_REV, NULL, 10);
}

==> gnucash_2.4.2.orig.tar.bz2: gnucash-2.4.2/src/core-utils/gnc-main.c <==
/*
 * gnc-main.c:
 *
 * Copyright (C) 2006 Chris Shoemaker <c.shoemaker@cox.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, contact:
 *
 * Free Software Foundation           Voice:  +1-617-542-5942
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
 * Boston, MA  02110-1301,  USA       gnu@gnu.org
 */

#include <stdlib.h>
#include "config.h"
#include "gnc-main.h"
#include "core-utils/gnc-version.h"

static gchar *namespace_regexp = NULL;
static gboolean is_debugging = 0;
static gboolean extras_enabled = 0;
static const gchar *gconf_path;

void
gnc_main_set_namespace_regexp(const gchar *str)
{
    if (namespace_regexp)
        g_free(namespace_regexp);

    if (str)
        namespace_regexp = g_strdup(str);
}

const gchar *
gnc_main_get_namespace_regexp(void)
{
    return namespace_regexp;
}

gboolean
gnc_is_debugging(void)
{
    return is_debugging;
}

void
gnc_set_debugging(gboolean d)
{
    is_debugging = d;
}

gboolean
gnc_is_extra_enabled(void)
{
    return extras_enabled;
}

void
gnc_set_extra(gboolean enabled)
{
    extras_enabled = enabled;
}

void
gnc_set_gconf_path (const gchar *path)
{
    gconf_path = path;
}

const gchar *
gnc_get_gconf_path (void)
{
    return gconf_path;
}

gint
gnc_get_svn_version (void)
{
    return strtol(GNUCASH_SVN_REV, NULL, 10);
}

guint
gnc_get_long_version()
{
return GNUCASH_MAJOR_VERSION * 1000000 +
    GNUCASH_MINOR_VERSION * 10000 +
    GNUCASH_MICRO_VERSION * 100 +
    GNUCASH_NANO_VERSION;
}
